import { GridNext, defaultGridNextConfig, gridNextShadowOptions } from '@genesislcap/grid-next';
import { zeroGridNextStyles as styles } from './grid-next.styles';
import { zeroGridNextTemplate as template } from './grid-next.template';
import { themeGenesisRapidDarkName, themeGenesisRapidName } from './themes';
const defaultRowHeaderHeight = 34;
const defaultRapidTheme = 'tabulator-theme-genesis-rapid-dark';
/**
 * @tagname %%prefix%%-grid-next
 */
export class ZeroGridNext extends GridNext {
    constructor() {
        super(...arguments);
        /**
         * Sets default theme to Rapid
         * @override
         */
        this.theme = defaultRapidTheme;
    }
    themeChanged(oldValue, newValue) {
        if (!oldValue && newValue !== defaultRapidTheme)
            return;
        super.themeChanged(oldValue, newValue);
    }
    /**
     * Handles extra ZERO configs
     * @override
     */
    set gridOptions(options) {
        // options.components = {
        //   [GridNextRendererTypes.action]: ZeroAgActionRenderer,
        //   [GridNextRendererTypes.actionsMenu]: ZeroAgActionsMenuRenderer,
        //   [GridNextRendererTypes.boolean]: ZeroBooleanRenderer,
        // };
        var _a;
        const isRapidTheme = this.theme === themeGenesisRapidName || this.theme === themeGenesisRapidDarkName;
        if (isRapidTheme) {
            // this.headerHeight = options.headerHeight ?? defaultRowHeaderHeight;
            this.rowHeight = (_a = options.rowHeight) !== null && _a !== void 0 ? _a : defaultRowHeaderHeight;
        }
        super.gridOptions = options;
    }
}
// explicitly declaring for extensibility
export const zeroGridNextShadowOptions = gridNextShadowOptions;
export const zeroDefaultGridNextConfig = defaultGridNextConfig;
export const zeroGridNext = ZeroGridNext.compose(Object.assign({ baseName: 'grid-next', template,
    styles, shadowOptions: zeroGridNextShadowOptions }, zeroDefaultGridNextConfig));
